# -*- coding: utf-8 -*-
import datetime

from repositories.pedido.models import PedidoVendaSituacao, PedidoVendaFormaPagamento, PedidoVenda


class SituacaoPedido(PedidoVendaSituacao):
    class Meta:
        proxy = True


class PedidoPagamento(PedidoVendaFormaPagamento):
    class Meta:
        proxy = True


class Pedido(PedidoVenda):
    class Meta:
        proxy = True
